@@ -11,3 +11,8 @@ class ITicketCloner(Interface):
         Given a ticket to clone, return a dictionary of fields
         and their values that should be present in the new ticket.
         """
+
+    def get_clone_form_action(req, ticket, data):
+        """
+        Given a ticket to clone, return a URL to submit the form to.
+        """
